@@ -48,7 +48,7 @@ class Builder:
 
     @staticmethod
     def path_join(folder: gsimplify.typedefs.FolderType, prefix: str = "./build/"):
-        return prefix + "/".join(folder.path) + "/"
+        return prefix + "/".join(folder.path).replace(" ","_").lower() + "/"
 
     def construct_folder_tree(
         self, path: list = [], start_folder: str = None
@@ -154,7 +154,7 @@ class Builder:
             if not os.path.exists(path):
                 os.mkdir(path)
 
-            with open(path + each_file.pointer.lower(), "wb") as f:
+            with open(path + each_file.pointer.lower().replace(" ", "_"), "wb") as f:
                 file_handler = self.drive.service.files().get_media(fileId=each_file.id)
                 downloader = MediaIoBaseDownload(f, file_handler)  # from google's docs
 
